@@ -23,19 +23,27 @@
 /**
  * Imports.
  */
+import { AmountJson } from "../amounts";
+
 import {
-  AmountJson,
   CoinRecord,
-  CoinWithDenom,
-  ContractTerms,
   DenominationRecord,
-  PayCoinInfo,
-  PaybackRequest,
   PreCoinRecord,
   RefreshSessionRecord,
   ReserveRecord,
+  TipPlanchet,
   WireFee,
-} from "../types";
+} from "../dbTypes";
+
+import {
+  ContractTerms,
+  PaybackRequest,
+} from "../talerTypes";
+
+import {
+  CoinWithDenom,
+  PayCoinInfo,
+} from "../walletTypes";
 
 import * as timer from "../timer";
 
@@ -72,6 +80,11 @@ interface WorkItem {
    * Serial id to identify a matching response.
    */
   rpcId: number;
+
+  /**
+   * Time when the work was submitted to a (non-busy) worker thread.
+   */
+  startTime: number;
 }
 
 
@@ -116,6 +129,7 @@ export class CryptoApi {
       operation: work.operation,
     };
     this.resetWorkerTimeout(ws);
+    work.startTime = timer.performanceNow();
     ws.w!.postMessage(msg);
   }
 
@@ -186,6 +200,7 @@ export class CryptoApi {
       console.error(`RPC with id ${id} has no registry entry`);
       return;
     }
+    console.log(`rpc ${currentWorkItem.operation} took ${timer.performanceNow() - currentWorkItem.startTime}ms`);
     currentWorkItem.resolve(msg.data.result);
   }
 
@@ -195,6 +210,7 @@ export class CryptoApi {
       // only works in the browser
       // tslint:disable-next-line:no-string-literal
       concurrency = (navigator as any)["hardwareConcurrency"];
+      concurrency = Math.max(1, Math.ceil(concurrency / 2));
     } catch (e) {
       // ignore
     }
@@ -215,11 +231,10 @@ export class CryptoApi {
 
   private doRpc<T>(operation: string, priority: number,
                    ...args: any[]): Promise<T> {
-    const start = timer.performanceNow();
 
-    const p = new Promise((resolve, reject) => {
+    const p: Promise<T> = new Promise<T>((resolve, reject) => {
       const rpcId = this.nextRpcId++;
-      const workItem: WorkItem = {operation, args, resolve, reject, rpcId};
+      const workItem: WorkItem = {operation, args, resolve, reject, rpcId, startTime: 0};
 
       if (this.numBusy === this.workers.length) {
         const q = this.workQueues[priority];
@@ -243,7 +258,6 @@ export class CryptoApi {
     });
 
     return p.then((r: T) => {
-      console.log(`rpc ${operation} took ${timer.performanceNow() - start}ms`);
       return r;
     });
   }
@@ -253,6 +267,10 @@ export class CryptoApi {
     return this.doRpc<PreCoinRecord>("createPreCoin", 1, denom, reserve);
   }
 
+  createTipPlanchet(denom: DenominationRecord): Promise<TipPlanchet> {
+    return this.doRpc<TipPlanchet>("createTipPlanchet", 1, denom);
+  }
+
   hashString(str: string): Promise<string> {
     return this.doRpc<string>("hashString", 1, str);
   }
@@ -270,13 +288,14 @@ export class CryptoApi {
     return this.doRpc<boolean>("isValidWireFee", 2, type, wf, masterPub);
   }
 
-  isValidPaymentSignature(sig: string, contractHash: string, merchantPub: string) {
-    return this.doRpc<PayCoinInfo>("isValidPaymentSignature", 1, sig, contractHash, merchantPub);
+  isValidPaymentSignature(sig: string, contractHash: string, merchantPub: string): Promise<boolean> {
+    return this.doRpc<boolean>("isValidPaymentSignature", 1, sig, contractHash, merchantPub);
   }
 
   signDeposit(contractTerms: ContractTerms,
-              cds: CoinWithDenom[]): Promise<PayCoinInfo> {
-    return this.doRpc<PayCoinInfo>("signDeposit", 3, contractTerms, cds);
+              cds: CoinWithDenom[],
+              totalAmount: AmountJson): Promise<PayCoinInfo> {
+    return this.doRpc<PayCoinInfo>("signDeposit", 3, contractTerms, cds, totalAmount);
   }
 
   createEddsaKeypair(): Promise<{priv: string, pub: string}> {
