@@ -22,26 +22,33 @@
 /**
  * Imports.
  */
+import * as Amounts from "../amounts";
+import { AmountJson } from "../amounts";
+
 import {
-  canonicalJson,
-} from "../helpers";
-import {
-  AmountJson,
-  Amounts,
-  CoinPaySig,
   CoinRecord,
   CoinStatus,
-  CoinWithDenom,
-  ContractTerms,
   DenominationRecord,
-  PayCoinInfo,
-  PaybackRequest,
   PreCoinRecord,
   RefreshPreCoinRecord,
   RefreshSessionRecord,
   ReserveRecord,
+  TipPlanchet,
   WireFee,
-} from "../types";
+} from "../dbTypes";
+
+import {
+  CoinPaySig,
+  ContractTerms,
+  PaybackRequest,
+} from "../talerTypes";
+
+import {
+  CoinWithDenom,
+  PayCoinInfo,
+} from "../walletTypes";
+
+import { canonicalJson } from "../helpers";
 
 import {
   Amount,
@@ -103,6 +110,7 @@ namespace RpcFunctions {
       coinValue: denom.value,
       denomPub: denomPub.encode().toCrock(),
       exchangeBaseUrl: reserve.exchange_base_url,
+      isFromTip: false,
       reservePub: reservePub.toCrock(),
       withdrawSig: sig.toCrock(),
     };
@@ -110,6 +118,38 @@ namespace RpcFunctions {
   }
 
 
+  /**
+   * Create a planchet used for tipping, including the private keys.
+   */
+  export function createTipPlanchet(denom: DenominationRecord): TipPlanchet {
+    const denomPub = native.RsaPublicKey.fromCrock(denom.denomPub);
+    const coinPriv = native.EddsaPrivateKey.create();
+    const coinPub = coinPriv.getPublicKey();
+    const blindingFactor = native.RsaBlindingKeySecret.create();
+    const pubHash: native.HashCode = coinPub.hash();
+    const ev = native.rsaBlind(pubHash, blindingFactor, denomPub);
+
+    if (!ev) {
+      throw Error("couldn't blind (malicious exchange key?)");
+    }
+
+    if (!denom.feeWithdraw) {
+      throw Error("Field fee_withdraw missing");
+    }
+
+    const tipPlanchet: TipPlanchet = {
+      blindingKey: blindingFactor.toCrock(),
+      coinEv: ev.toCrock(),
+      coinPriv: coinPriv.toCrock(),
+      coinPub: coinPub.toCrock(),
+      coinValue: denom.value,
+      denomPub: denomPub.encode().toCrock(),
+      denomPubHash: denomPub.encode().hash().toCrock(),
+    };
+    return tipPlanchet;
+  }
+
+
   /**
    * Create and sign a message to request payback for a coin.
    */
@@ -229,21 +269,27 @@ namespace RpcFunctions {
    * and deposit permissions for each given coin.
    */
   export function signDeposit(contractTerms: ContractTerms,
-                              cds: CoinWithDenom[]): PayCoinInfo {
-    const ret: PayCoinInfo = [];
+                              cds: CoinWithDenom[],
+                              totalAmount: AmountJson): PayCoinInfo {
+    const ret: PayCoinInfo = {
+      originalCoins: [],
+      sigs: [],
+      updatedCoins: [],
+    };
 
     const contractTermsHash = hashString(canonicalJson(contractTerms));
 
     const feeList: AmountJson[] = cds.map((x) => x.denom.feeDeposit);
     let fees = Amounts.add(Amounts.getZero(feeList[0].currency), ...feeList).amount;
     // okay if saturates
-    fees = Amounts.sub(fees, contractTerms.max_fee).amount;
-    const total = Amounts.add(fees, contractTerms.amount).amount;
+    fees = Amounts.sub(fees, Amounts.parseOrThrow(contractTerms.max_fee)).amount;
+    const total = Amounts.add(fees, totalAmount).amount;
 
     const amountSpent = native.Amount.getZero(cds[0].coin.currentAmount.currency);
     const amountRemaining = new native.Amount(total);
     for (const cd of cds) {
       let coinSpend: Amount;
+      const originalCoin = { ...(cd.coin) };
 
       if (amountRemaining.value === 0 && amountRemaining.fraction === 0) {
         break;
@@ -289,11 +335,14 @@ namespace RpcFunctions {
       const s: CoinPaySig = {
         coin_pub: cd.coin.coinPub,
         coin_sig: coinSig,
+        contribution: Amounts.toString(coinSpend.toJson()),
         denom_pub: cd.coin.denomPub,
-        f: coinSpend.toJson(),
+        exchange_url: cd.denom.exchangeBaseUrl,
         ub_sig: cd.coin.denomSig,
       };
-      ret.push({sig: s, updatedCoin: cd.coin});
+      ret.sigs.push(s);
+      ret.updatedCoins.push(cd.coin);
+      ret.originalCoins.push(originalCoin);
     }
     return ret;
   }
@@ -402,6 +451,7 @@ namespace RpcFunctions {
       finished: false,
       hash: sessionHash.toCrock(),
       meltCoinPub: meltCoin.coinPub,
+      newDenomHashes: newCoinDenoms.map((d) => d.denomPubHash),
       newDenoms: newCoinDenoms.map((d) => d.denomPub),
       norevealIndex: undefined,
       preCoinsForGammas,
