@@ -24,7 +24,7 @@ strings['de'] = {
         "plural_forms": "nplurals=2; plural=(n != 1);",
         "lang": ""
       },
-      "show more details\n": [
+      "show more details": [
         ""
       ],
       "Accepted exchanges:": [
@@ -39,34 +39,34 @@ strings['de'] = {
       "You do not have any funds from an exchange that is accepted by this merchant. None of the exchanges accepted by the merchant is known to your wallet.": [
         ""
       ],
-      "The merchant%1$s offers you to purchase:\n": [
-        ""
-      ],
       "Confirm payment": [
         "Bezahlung bestätigen"
       ],
-      "Withdrawal fees:": [
-        "Abheben bei %1$s"
-      ],
-      "Rounding loss:": [
+      "Submitting payment": [
         ""
       ],
-      "Earliest expiration (for deposit): %1$s": [
+      "You already paid for this, clicking \"Confirm payment\" will not cost money again.": [
         ""
       ],
-      "# Coins": [
+      "Aborting payment ...": [
+        "Bezahlung bestätigen"
+      ],
+      "Payment aborted!": [
         ""
       ],
-      "Value": [
+      "Retry Payment": [
+        "Bezahlung bestätigen"
+      ],
+      "Abort Payment": [
+        "Bezahlung bestätigen"
+      ],
+      "The merchant %1$s offers you to purchase:": [
+        "Der Händler %1$s möchte einen Vertrag über %2$s mit Ihnen abschließen."
+      ],
+      "The total price is %1$s (plus %2$s fees).": [
         ""
       ],
-      "Withdraw Fee": [
-        "Abheben bei %1$s"
-      ],
-      "Refresh Fee": [
-        ""
-      ],
-      "Deposit Fee": [
+      "The total price is %1$s.": [
         ""
       ],
       "Select": [
@@ -75,30 +75,45 @@ strings['de'] = {
       "Error: URL may not be relative": [
         ""
       ],
-      "The exchange is trusted by the wallet.\n": [
+      "Invalid exchange URL (%1$s)": [
         ""
       ],
-      "The exchange is audited by a trusted auditor.\n": [
+      "The exchange is trusted by the wallet.": [
         ""
       ],
-      "Warning:  The exchange is neither directly trusted nor audited by a trusted auditor.\nIf you withdraw from this exchange, it will be trusted in the future.\n": [
+      "The exchange is audited by a trusted auditor.": [
         ""
       ],
-      "Using exchange provider%1$s.\nThe exchange provider will charge\n %2$s in fees.\n": [
+      "Warning: The exchange is neither directly trusted nor audited by a trusted auditor. If you withdraw from this exchange, it will be trusted in the future.": [
         ""
       ],
-      "Waiting for a response from\n %1$s": [
+      "Using exchange provider %1$s. The exchange provider will charge %2$s in fees.": [
+        ""
+      ],
+      "Waiting for a response from %1$s %2$s": [
         ""
       ],
       "Information about fees will be available when an exchange provider is selected.": [
         ""
       ],
+      "Your wallet (protocol version %1$s) might be outdated.%2$s The exchange has a higher, incompatible protocol version (%3$s).": [
+        ""
+      ],
+      "The chosen exchange (protocol version %1$s might be outdated.%2$s The exchange has a lower, incompatible protocol version than your wallet (protocol version %3$s).": [
+        ""
+      ],
       "Accept fees and withdraw": [
         ""
       ],
       "Change Exchange Provider": [
         ""
       ],
+      "Please select an exchange.  You can review the details before after your selection.": [
+        ""
+      ],
+      "Select %1$s": [
+        ""
+      ],
       "You are about to withdraw %1$s from your bank account into your wallet.": [
         ""
       ],
@@ -129,13 +144,13 @@ strings['de'] = {
       "help": [
         ""
       ],
-      "You have no balance to show. Need some\n %1$s getting started?\n": [
+      "You have no balance to show. Need some %1$s getting started?": [
         "Sie haben kein Digitalgeld. Wollen Sie %1$s? abheben?"
       ],
-      "%1$s incoming\n": [
+      "%1$s incoming": [
         ""
       ],
-      "%1$s being spent\n": [
+      "%1$s being spent": [
         ""
       ],
       "Error: could not retrieve balance information.": [
@@ -150,22 +165,31 @@ strings['de'] = {
       "Manage Trusted Auditors and Exchanges": [
         ""
       ],
-      "Bank requested reserve (%1$s) for\n %2$s.\n": [
+      "Bank requested reserve (%1$s) for %2$s.": [
         "Bank bestätig anlegen der Reserve (%1$s) bei %2$s"
       ],
-      "Started to withdraw\n %1$s%2$sfrom%3$s(%4$s).\n": [
+      "Started to withdraw %1$s from %2$s (%3$s).": [
         "Reserve (%1$s) mit %2$s bei %3$s erzeugt"
       ],
-      "Merchant%1$soffered%2$scontract%3$s.\n": [
+      "Merchant %1$s offered contract %2$s.": [
         "%1$s\n               möchte einen Vertrag über %2$s\n               mit Ihnen abschließen."
       ],
-      "Withdrew%1$sfrom%2$s(%3$s).\n": [
+      "Withdrew %1$s from %2$s (%3$s).": [
         "Reserve (%1$s) mit %2$s bei %3$s erzeugt"
       ],
-      "Paid%1$sto merchant%2$s.\n%3$s(%4$s)\n": [
+      "Paid %1$s to merchant %2$s. %3$s (%4$s)": [
         "Reserve (%1$s) mit %2$s bei %3$s erzeugt"
       ],
-      "Merchant%1$sgave a refund over%2$s.\n": [
+      "Merchant %1$s gave a refund over %2$s.": [
+        "%1$s\n               möchte einen Vertrag über %2$s\n               mit Ihnen abschließen."
+      ],
+      "tip": [
+        ""
+      ],
+      "Merchant %1$s gave a %2$s of %3$s.": [
+        "%1$s\n               möchte einen Vertrag über %2$s\n               mit Ihnen abschließen."
+      ],
+      "You did not accept the tip yet.": [
         ""
       ],
       "Unknown event (%1$s)": [
@@ -186,6 +210,30 @@ strings['de'] = {
       "Cancel": [
         "Saldo"
       ],
+      "Withdrawal fees:": [
+        "Abheben bei"
+      ],
+      "Rounding loss:": [
+        ""
+      ],
+      "Earliest expiration (for deposit): %1$s": [
+        ""
+      ],
+      "# Coins": [
+        ""
+      ],
+      "Value": [
+        ""
+      ],
+      "Withdraw Fee": [
+        "Abheben bei %1$s"
+      ],
+      "Refresh Fee": [
+        ""
+      ],
+      "Deposit Fee": [
+        ""
+      ],
       "Invalid Wire": [
         ""
       ],
@@ -210,7 +258,7 @@ strings['en-US'] = {
         "plural_forms": "nplurals=2; plural=(n != 1);",
         "lang": ""
       },
-      "show more details\n": [
+      "show more details": [
         ""
       ],
       "Accepted exchanges:": [
@@ -225,34 +273,34 @@ strings['en-US'] = {
       "You do not have any funds from an exchange that is accepted by this merchant. None of the exchanges accepted by the merchant is known to your wallet.": [
         ""
       ],
-      "The merchant%1$s offers you to purchase:\n": [
-        ""
-      ],
       "Confirm payment": [
         ""
       ],
-      "Withdrawal fees:": [
+      "Submitting payment": [
         ""
       ],
-      "Rounding loss:": [
+      "You already paid for this, clicking \"Confirm payment\" will not cost money again.": [
         ""
       ],
-      "Earliest expiration (for deposit): %1$s": [
+      "Aborting payment ...": [
         ""
       ],
-      "# Coins": [
+      "Payment aborted!": [
         ""
       ],
-      "Value": [
+      "Retry Payment": [
         ""
       ],
-      "Withdraw Fee": [
+      "Abort Payment": [
         ""
       ],
-      "Refresh Fee": [
+      "The merchant %1$s offers you to purchase:": [
         ""
       ],
-      "Deposit Fee": [
+      "The total price is %1$s (plus %2$s fees).": [
+        ""
+      ],
+      "The total price is %1$s.": [
         ""
       ],
       "Select": [
@@ -261,30 +309,45 @@ strings['en-US'] = {
       "Error: URL may not be relative": [
         ""
       ],
-      "The exchange is trusted by the wallet.\n": [
+      "Invalid exchange URL (%1$s)": [
         ""
       ],
-      "The exchange is audited by a trusted auditor.\n": [
+      "The exchange is trusted by the wallet.": [
         ""
       ],
-      "Warning:  The exchange is neither directly trusted nor audited by a trusted auditor.\nIf you withdraw from this exchange, it will be trusted in the future.\n": [
+      "The exchange is audited by a trusted auditor.": [
         ""
       ],
-      "Using exchange provider%1$s.\nThe exchange provider will charge\n %2$s in fees.\n": [
+      "Warning: The exchange is neither directly trusted nor audited by a trusted auditor. If you withdraw from this exchange, it will be trusted in the future.": [
         ""
       ],
-      "Waiting for a response from\n %1$s": [
+      "Using exchange provider %1$s. The exchange provider will charge %2$s in fees.": [
+        ""
+      ],
+      "Waiting for a response from %1$s %2$s": [
         ""
       ],
       "Information about fees will be available when an exchange provider is selected.": [
         ""
       ],
+      "Your wallet (protocol version %1$s) might be outdated.%2$s The exchange has a higher, incompatible protocol version (%3$s).": [
+        ""
+      ],
+      "The chosen exchange (protocol version %1$s might be outdated.%2$s The exchange has a lower, incompatible protocol version than your wallet (protocol version %3$s).": [
+        ""
+      ],
       "Accept fees and withdraw": [
         ""
       ],
       "Change Exchange Provider": [
         ""
       ],
+      "Please select an exchange.  You can review the details before after your selection.": [
+        ""
+      ],
+      "Select %1$s": [
+        ""
+      ],
       "You are about to withdraw %1$s from your bank account into your wallet.": [
         ""
       ],
@@ -315,13 +378,13 @@ strings['en-US'] = {
       "help": [
         ""
       ],
-      "You have no balance to show. Need some\n %1$s getting started?\n": [
+      "You have no balance to show. Need some %1$s getting started?": [
         ""
       ],
-      "%1$s incoming\n": [
+      "%1$s incoming": [
         ""
       ],
-      "%1$s being spent\n": [
+      "%1$s being spent": [
         ""
       ],
       "Error: could not retrieve balance information.": [
@@ -336,22 +399,31 @@ strings['en-US'] = {
       "Manage Trusted Auditors and Exchanges": [
         ""
       ],
-      "Bank requested reserve (%1$s) for\n %2$s.\n": [
+      "Bank requested reserve (%1$s) for %2$s.": [
         ""
       ],
-      "Started to withdraw\n %1$s%2$sfrom%3$s(%4$s).\n": [
+      "Started to withdraw %1$s from %2$s (%3$s).": [
         ""
       ],
-      "Merchant%1$soffered%2$scontract%3$s.\n": [
+      "Merchant %1$s offered contract %2$s.": [
         ""
       ],
-      "Withdrew%1$sfrom%2$s(%3$s).\n": [
+      "Withdrew %1$s from %2$s (%3$s).": [
         ""
       ],
-      "Paid%1$sto merchant%2$s.\n%3$s(%4$s)\n": [
+      "Paid %1$s to merchant %2$s. %3$s (%4$s)": [
         ""
       ],
-      "Merchant%1$sgave a refund over%2$s.\n": [
+      "Merchant %1$s gave a refund over %2$s.": [
+        ""
+      ],
+      "tip": [
+        ""
+      ],
+      "Merchant %1$s gave a %2$s of %3$s.": [
+        ""
+      ],
+      "You did not accept the tip yet.": [
         ""
       ],
       "Unknown event (%1$s)": [
@@ -372,6 +444,30 @@ strings['en-US'] = {
       "Cancel": [
         ""
       ],
+      "Withdrawal fees:": [
+        ""
+      ],
+      "Rounding loss:": [
+        ""
+      ],
+      "Earliest expiration (for deposit): %1$s": [
+        ""
+      ],
+      "# Coins": [
+        ""
+      ],
+      "Value": [
+        ""
+      ],
+      "Withdraw Fee": [
+        ""
+      ],
+      "Refresh Fee": [
+        ""
+      ],
+      "Deposit Fee": [
+        ""
+      ],
       "Invalid Wire": [
         ""
       ],
@@ -396,7 +492,7 @@ strings['fr'] = {
         "plural_forms": "nplurals=2; plural=(n != 1);",
         "lang": ""
       },
-      "show more details\n": [
+      "show more details": [
         ""
       ],
       "Accepted exchanges:": [
@@ -411,34 +507,34 @@ strings['fr'] = {
       "You do not have any funds from an exchange that is accepted by this merchant. None of the exchanges accepted by the merchant is known to your wallet.": [
         ""
       ],
-      "The merchant%1$s offers you to purchase:\n": [
-        ""
-      ],
       "Confirm payment": [
         ""
       ],
-      "Withdrawal fees:": [
+      "Submitting payment": [
         ""
       ],
-      "Rounding loss:": [
+      "You already paid for this, clicking \"Confirm payment\" will not cost money again.": [
         ""
       ],
-      "Earliest expiration (for deposit): %1$s": [
+      "Aborting payment ...": [
         ""
       ],
-      "# Coins": [
+      "Payment aborted!": [
         ""
       ],
-      "Value": [
+      "Retry Payment": [
         ""
       ],
-      "Withdraw Fee": [
+      "Abort Payment": [
         ""
       ],
-      "Refresh Fee": [
+      "The merchant %1$s offers you to purchase:": [
         ""
       ],
-      "Deposit Fee": [
+      "The total price is %1$s (plus %2$s fees).": [
+        ""
+      ],
+      "The total price is %1$s.": [
         ""
       ],
       "Select": [
@@ -447,30 +543,45 @@ strings['fr'] = {
       "Error: URL may not be relative": [
         ""
       ],
-      "The exchange is trusted by the wallet.\n": [
+      "Invalid exchange URL (%1$s)": [
         ""
       ],
-      "The exchange is audited by a trusted auditor.\n": [
+      "The exchange is trusted by the wallet.": [
         ""
       ],
-      "Warning:  The exchange is neither directly trusted nor audited by a trusted auditor.\nIf you withdraw from this exchange, it will be trusted in the future.\n": [
+      "The exchange is audited by a trusted auditor.": [
         ""
       ],
-      "Using exchange provider%1$s.\nThe exchange provider will charge\n %2$s in fees.\n": [
+      "Warning: The exchange is neither directly trusted nor audited by a trusted auditor. If you withdraw from this exchange, it will be trusted in the future.": [
         ""
       ],
-      "Waiting for a response from\n %1$s": [
+      "Using exchange provider %1$s. The exchange provider will charge %2$s in fees.": [
+        ""
+      ],
+      "Waiting for a response from %1$s %2$s": [
         ""
       ],
       "Information about fees will be available when an exchange provider is selected.": [
         ""
       ],
+      "Your wallet (protocol version %1$s) might be outdated.%2$s The exchange has a higher, incompatible protocol version (%3$s).": [
+        ""
+      ],
+      "The chosen exchange (protocol version %1$s might be outdated.%2$s The exchange has a lower, incompatible protocol version than your wallet (protocol version %3$s).": [
+        ""
+      ],
       "Accept fees and withdraw": [
         ""
       ],
       "Change Exchange Provider": [
         ""
       ],
+      "Please select an exchange.  You can review the details before after your selection.": [
+        ""
+      ],
+      "Select %1$s": [
+        ""
+      ],
       "You are about to withdraw %1$s from your bank account into your wallet.": [
         ""
       ],
@@ -501,13 +612,13 @@ strings['fr'] = {
       "help": [
         ""
       ],
-      "You have no balance to show. Need some\n %1$s getting started?\n": [
+      "You have no balance to show. Need some %1$s getting started?": [
         ""
       ],
-      "%1$s incoming\n": [
+      "%1$s incoming": [
         ""
       ],
-      "%1$s being spent\n": [
+      "%1$s being spent": [
         ""
       ],
       "Error: could not retrieve balance information.": [
@@ -522,22 +633,31 @@ strings['fr'] = {
       "Manage Trusted Auditors and Exchanges": [
         ""
       ],
-      "Bank requested reserve (%1$s) for\n %2$s.\n": [
+      "Bank requested reserve (%1$s) for %2$s.": [
         ""
       ],
-      "Started to withdraw\n %1$s%2$sfrom%3$s(%4$s).\n": [
+      "Started to withdraw %1$s from %2$s (%3$s).": [
         ""
       ],
-      "Merchant%1$soffered%2$scontract%3$s.\n": [
+      "Merchant %1$s offered contract %2$s.": [
         ""
       ],
-      "Withdrew%1$sfrom%2$s(%3$s).\n": [
+      "Withdrew %1$s from %2$s (%3$s).": [
         ""
       ],
-      "Paid%1$sto merchant%2$s.\n%3$s(%4$s)\n": [
+      "Paid %1$s to merchant %2$s. %3$s (%4$s)": [
         ""
       ],
-      "Merchant%1$sgave a refund over%2$s.\n": [
+      "Merchant %1$s gave a refund over %2$s.": [
+        ""
+      ],
+      "tip": [
+        ""
+      ],
+      "Merchant %1$s gave a %2$s of %3$s.": [
+        ""
+      ],
+      "You did not accept the tip yet.": [
         ""
       ],
       "Unknown event (%1$s)": [
@@ -558,6 +678,30 @@ strings['fr'] = {
       "Cancel": [
         ""
       ],
+      "Withdrawal fees:": [
+        ""
+      ],
+      "Rounding loss:": [
+        ""
+      ],
+      "Earliest expiration (for deposit): %1$s": [
+        ""
+      ],
+      "# Coins": [
+        ""
+      ],
+      "Value": [
+        ""
+      ],
+      "Withdraw Fee": [
+        ""
+      ],
+      "Refresh Fee": [
+        ""
+      ],
+      "Deposit Fee": [
+        ""
+      ],
       "Invalid Wire": [
         ""
       ],
@@ -582,7 +726,7 @@ strings['it'] = {
         "plural_forms": "nplurals=2; plural=(n != 1);",
         "lang": ""
       },
-      "show more details\n": [
+      "show more details": [
         ""
       ],
       "Accepted exchanges:": [
@@ -597,34 +741,34 @@ strings['it'] = {
       "You do not have any funds from an exchange that is accepted by this merchant. None of the exchanges accepted by the merchant is known to your wallet.": [
         ""
       ],
-      "The merchant%1$s offers you to purchase:\n": [
-        ""
-      ],
       "Confirm payment": [
         ""
       ],
-      "Withdrawal fees:": [
+      "Submitting payment": [
         ""
       ],
-      "Rounding loss:": [
+      "You already paid for this, clicking \"Confirm payment\" will not cost money again.": [
         ""
       ],
-      "Earliest expiration (for deposit): %1$s": [
+      "Aborting payment ...": [
         ""
       ],
-      "# Coins": [
+      "Payment aborted!": [
         ""
       ],
-      "Value": [
+      "Retry Payment": [
         ""
       ],
-      "Withdraw Fee": [
+      "Abort Payment": [
         ""
       ],
-      "Refresh Fee": [
+      "The merchant %1$s offers you to purchase:": [
         ""
       ],
-      "Deposit Fee": [
+      "The total price is %1$s (plus %2$s fees).": [
+        ""
+      ],
+      "The total price is %1$s.": [
         ""
       ],
       "Select": [
@@ -633,30 +777,45 @@ strings['it'] = {
       "Error: URL may not be relative": [
         ""
       ],
-      "The exchange is trusted by the wallet.\n": [
+      "Invalid exchange URL (%1$s)": [
         ""
       ],
-      "The exchange is audited by a trusted auditor.\n": [
+      "The exchange is trusted by the wallet.": [
         ""
       ],
-      "Warning:  The exchange is neither directly trusted nor audited by a trusted auditor.\nIf you withdraw from this exchange, it will be trusted in the future.\n": [
+      "The exchange is audited by a trusted auditor.": [
         ""
       ],
-      "Using exchange provider%1$s.\nThe exchange provider will charge\n %2$s in fees.\n": [
+      "Warning: The exchange is neither directly trusted nor audited by a trusted auditor. If you withdraw from this exchange, it will be trusted in the future.": [
         ""
       ],
-      "Waiting for a response from\n %1$s": [
+      "Using exchange provider %1$s. The exchange provider will charge %2$s in fees.": [
+        ""
+      ],
+      "Waiting for a response from %1$s %2$s": [
         ""
       ],
       "Information about fees will be available when an exchange provider is selected.": [
         ""
       ],
+      "Your wallet (protocol version %1$s) might be outdated.%2$s The exchange has a higher, incompatible protocol version (%3$s).": [
+        ""
+      ],
+      "The chosen exchange (protocol version %1$s might be outdated.%2$s The exchange has a lower, incompatible protocol version than your wallet (protocol version %3$s).": [
+        ""
+      ],
       "Accept fees and withdraw": [
         ""
       ],
       "Change Exchange Provider": [
         ""
       ],
+      "Please select an exchange.  You can review the details before after your selection.": [
+        ""
+      ],
+      "Select %1$s": [
+        ""
+      ],
       "You are about to withdraw %1$s from your bank account into your wallet.": [
         ""
       ],
@@ -687,13 +846,13 @@ strings['it'] = {
       "help": [
         ""
       ],
-      "You have no balance to show. Need some\n %1$s getting started?\n": [
+      "You have no balance to show. Need some %1$s getting started?": [
         ""
       ],
-      "%1$s incoming\n": [
+      "%1$s incoming": [
         ""
       ],
-      "%1$s being spent\n": [
+      "%1$s being spent": [
         ""
       ],
       "Error: could not retrieve balance information.": [
@@ -708,22 +867,31 @@ strings['it'] = {
       "Manage Trusted Auditors and Exchanges": [
         ""
       ],
-      "Bank requested reserve (%1$s) for\n %2$s.\n": [
+      "Bank requested reserve (%1$s) for %2$s.": [
         ""
       ],
-      "Started to withdraw\n %1$s%2$sfrom%3$s(%4$s).\n": [
+      "Started to withdraw %1$s from %2$s (%3$s).": [
         ""
       ],
-      "Merchant%1$soffered%2$scontract%3$s.\n": [
+      "Merchant %1$s offered contract %2$s.": [
         ""
       ],
-      "Withdrew%1$sfrom%2$s(%3$s).\n": [
+      "Withdrew %1$s from %2$s (%3$s).": [
         ""
       ],
-      "Paid%1$sto merchant%2$s.\n%3$s(%4$s)\n": [
+      "Paid %1$s to merchant %2$s. %3$s (%4$s)": [
         ""
       ],
-      "Merchant%1$sgave a refund over%2$s.\n": [
+      "Merchant %1$s gave a refund over %2$s.": [
+        ""
+      ],
+      "tip": [
+        ""
+      ],
+      "Merchant %1$s gave a %2$s of %3$s.": [
+        ""
+      ],
+      "You did not accept the tip yet.": [
         ""
       ],
       "Unknown event (%1$s)": [
@@ -744,6 +912,264 @@ strings['it'] = {
       "Cancel": [
         ""
       ],
+      "Withdrawal fees:": [
+        ""
+      ],
+      "Rounding loss:": [
+        ""
+      ],
+      "Earliest expiration (for deposit): %1$s": [
+        ""
+      ],
+      "# Coins": [
+        ""
+      ],
+      "Value": [
+        ""
+      ],
+      "Withdraw Fee": [
+        ""
+      ],
+      "Refresh Fee": [
+        ""
+      ],
+      "Deposit Fee": [
+        ""
+      ],
+      "Invalid Wire": [
+        ""
+      ],
+      "Invalid Test Wire Detail": [
+        ""
+      ],
+      "Test Wire Acct #%1$s on %2$s": [
+        ""
+      ],
+      "Unknown Wire Detail": [
+        ""
+      ]
+    }
+  }
+};
+strings['sv'] = {
+  "domain": "messages",
+  "locale_data": {
+    "messages": {
+      "": {
+        "domain": "messages",
+        "plural_forms": "nplurals=2; plural=(n != 1);",
+        "lang": ""
+      },
+      "show more details": [
+        "visa mer"
+      ],
+      "Accepted exchanges:": [
+        "Accepterade tjänsteleverantörer:"
+      ],
+      "Exchanges in the wallet:": [
+        "Tjänsteleverantörer i plånboken:"
+      ],
+      "You have insufficient funds of the requested currency in your wallet.": [
+        "plånboken"
+      ],
+      "You do not have any funds from an exchange that is accepted by this merchant. None of the exchanges accepted by the merchant is known to your wallet.": [
+        "plånboken"
+      ],
+      "Confirm payment": [
+        "Godkän betalning"
+      ],
+      "Submitting payment": [
+        "Bekräftar betalning"
+      ],
+      "You already paid for this, clicking \"Confirm payment\" will not cost money again.": [
+        "Du har redan betalat för det här, om du trycker \"Godkän betalning\" debiteras du inte igen"
+      ],
+      "Aborting payment ...": [
+        ""
+      ],
+      "Payment aborted!": [
+        ""
+      ],
+      "Retry Payment": [
+        ""
+      ],
+      "Abort Payment": [
+        ""
+      ],
+      "The merchant %1$s offers you to purchase:": [
+        "Säljaren %1$s erbjuder följande:"
+      ],
+      "The total price is %1$s (plus %2$s fees).": [
+        "Det totala priset är %1$s (plus %2$s avgifter).\n"
+      ],
+      "The total price is %1$s.": [
+        "Det totala priset är %1$s."
+      ],
+      "Select": [
+        "Välj"
+      ],
+      "Error: URL may not be relative": [
+        ""
+      ],
+      "Invalid exchange URL (%1$s)": [
+        ""
+      ],
+      "The exchange is trusted by the wallet.": [
+        ""
+      ],
+      "The exchange is audited by a trusted auditor.": [
+        ""
+      ],
+      "Warning: The exchange is neither directly trusted nor audited by a trusted auditor. If you withdraw from this exchange, it will be trusted in the future.": [
+        ""
+      ],
+      "Using exchange provider %1$s. The exchange provider will charge %2$s in fees.": [
+        ""
+      ],
+      "Waiting for a response from %1$s %2$s": [
+        ""
+      ],
+      "Information about fees will be available when an exchange provider is selected.": [
+        ""
+      ],
+      "Your wallet (protocol version %1$s) might be outdated.%2$s The exchange has a higher, incompatible protocol version (%3$s).": [
+        "tjänsteleverantörer plånboken"
+      ],
+      "The chosen exchange (protocol version %1$s might be outdated.%2$s The exchange has a lower, incompatible protocol version than your wallet (protocol version %3$s).": [
+        "tjänsteleverantörer plånboken"
+      ],
+      "Accept fees and withdraw": [
+        "Acceptera avgifter och utbetala"
+      ],
+      "Change Exchange Provider": [
+        "Ändra tjänsteleverantörer"
+      ],
+      "Please select an exchange.  You can review the details before after your selection.": [
+        ""
+      ],
+      "Select %1$s": [
+        "Välj %1$s"
+      ],
+      "You are about to withdraw %1$s from your bank account into your wallet.": [
+        "Du är på väg att ta ut\n %1$s från ditt bankkonto till din plånbok.\n"
+      ],
+      "Oops, something went wrong. The wallet responded with error status (%1$s).": [
+        "plånboken"
+      ],
+      "Checking URL, please wait ...": [
+        ""
+      ],
+      "Can't parse amount: %1$s": [
+        ""
+      ],
+      "Can't parse wire_types: %1$s": [
+        ""
+      ],
+      "Fatal error: \"%1$s\".": [
+        ""
+      ],
+      "Balance": [
+        "Balans"
+      ],
+      "History": [
+        "Historia"
+      ],
+      "Debug": [
+        ""
+      ],
+      "help": [
+        "hjälp"
+      ],
+      "You have no balance to show. Need some %1$s getting started?": [
+        "Du har ingen balans att visa. Behöver du\n %1$s att börja?\n"
+      ],
+      "%1$s incoming": [
+        "%1$s inkommande"
+      ],
+      "%1$s being spent": [
+        ""
+      ],
+      "Error: could not retrieve balance information.": [
+        ""
+      ],
+      "Payback": [
+        "Återbetalning"
+      ],
+      "Return Electronic Cash to Bank Account": [
+        "Återlämna elektroniska pengar till bank konto"
+      ],
+      "Manage Trusted Auditors and Exchanges": [
+        ""
+      ],
+      "Bank requested reserve (%1$s) for %2$s.": [
+        ""
+      ],
+      "Started to withdraw %1$s from %2$s (%3$s).": [
+        ""
+      ],
+      "Merchant %1$s offered contract %2$s.": [
+        "Säljaren %1$s erbjöd kontrakt %2$s.\n"
+      ],
+      "Withdrew %1$s from %2$s (%3$s).": [
+        ""
+      ],
+      "Paid %1$s to merchant %2$s. %3$s (%4$s)": [
+        ""
+      ],
+      "Merchant %1$s gave a refund over %2$s.": [
+        "Säljaren %1$sgav en återbetalning på %2$s.\n"
+      ],
+      "tip": [
+        ""
+      ],
+      "Merchant %1$s gave a %2$s of %3$s.": [
+        "Säljaren %1$sgav en återbetalning på %2$s.\n"
+      ],
+      "You did not accept the tip yet.": [
+        ""
+      ],
+      "Unknown event (%1$s)": [
+        ""
+      ],
+      "Error: could not retrieve event history": [
+        ""
+      ],
+      "Your wallet has no events recorded.": [
+        "plånboken"
+      ],
+      "Wire to bank account": [
+        "Övervisa till bank konto"
+      ],
+      "Confirm": [
+        "Bekräfta"
+      ],
+      "Cancel": [
+        "Avbryt"
+      ],
+      "Withdrawal fees:": [
+        "Utbetalnings avgifter:"
+      ],
+      "Rounding loss:": [
+        ""
+      ],
+      "Earliest expiration (for deposit): %1$s": [
+        ""
+      ],
+      "# Coins": [
+        "# Mynt"
+      ],
+      "Value": [
+        "Värde"
+      ],
+      "Withdraw Fee": [
+        "Utbetalnings avgift"
+      ],
+      "Refresh Fee": [
+        "Återhämtnings avgift"
+      ],
+      "Deposit Fee": [
+        "Depostitions avgift"
+      ],
       "Invalid Wire": [
         ""
       ],
