@@ -50,6 +50,20 @@ export class Store<T> {
 }
 
 
+/**
+ * Options for an index.
+ */
+export interface IndexOptions {
+  /**
+   * If true and the path resolves to an array, create an index entry for
+   * each member of the array (instead of one index entry containing the full array).
+   *
+   * Defaults to false.
+   */
+  multiEntry?: boolean;
+}
+
+
 /**
  * Definition of an index.
  */
@@ -59,7 +73,16 @@ export class Index<S extends IDBValidKey, T> {
    */
   storeName: string;
 
-  constructor(s: Store<T>, public indexName: string, public keyPath: string | string[]) {
+  /**
+   * Options to use for the index.
+   */
+  options: IndexOptions;
+
+  constructor(s: Store<T>, public indexName: string, public keyPath: string | string[], options?: IndexOptions) {
+    const defaultOptions = {
+      multiEntry: false,
+    };
+    this.options = { ...defaultOptions, ...(options || {}) };
     this.storeName = s.name;
   }
 
@@ -104,9 +127,15 @@ export interface QueryStream<T> {
   filter(f: (x: T) => boolean): QueryStream<T>;
 
   /**
-   * Reduce the stream, resulting in a single value.
+   * Fold the stream, resulting in a single value.
    */
-  reduce<S>(f: (v: T, acc?: S) => S, start?: S): Promise<S>;
+  fold<S>(f: (v: T, acc: S) => S, start: S): Promise<S>;
+
+  /**
+   * Execute a function for every value of the stream, for the
+   * side-effects of the function.
+   */
+  forEach(f: (v: T) => void): Promise<void>;
 
   /**
    * Map each element of the stream using a function, resulting in another
@@ -301,7 +330,7 @@ abstract class QueryStreamBase<T> implements QueryStream<T> {
                   .then(() => promise);
   }
 
-  reduce<A>(f: (x: any, acc?: A) => A, init?: A): Promise<any> {
+  fold<A>(f: (x: T, acc: A) => A, init: A): Promise<A> {
     const {resolve, promise} = openPromise();
     let acc = init;
 
@@ -318,6 +347,22 @@ abstract class QueryStreamBase<T> implements QueryStream<T> {
                   .then(() => promise);
   }
 
+  forEach(f: (x: T) => void): Promise<void> {
+    const {resolve, promise} = openPromise();
+
+    this.subscribe((isDone, value) => {
+      if (isDone) {
+        resolve();
+        return;
+      }
+      f(value);
+    });
+
+    return Promise.resolve()
+                  .then(() => this.root.finish())
+                  .then(() => promise);
+  }
+
   run(): Promise<void> {
     const {resolve, promise} = openPromise();
 
@@ -652,6 +697,31 @@ export class QueryRoot {
     return this;
   }
 
+  /**
+   * Put an object into a store or return an existing record.
+   */
+  putOrGetExisting<T>(store: Store<T>, val: T, key: IDBValidKey): Promise<T> {
+    this.checkFinished();
+    const {resolve, promise} = openPromise();
+    const doPutOrGet = (tx: IDBTransaction) => {
+      const objstore = tx.objectStore(store.name);
+      const req = objstore.get(key);
+      req.onsuccess = () => {
+        if (req.result !== undefined) {
+          resolve(req.result);
+        } else {
+          const req2 = objstore.add(val);
+          req2.onsuccess = () => {
+            resolve(val);
+          };
+        }
+      };
+    };
+    this.scheduleFinish();
+    this.addWork(doPutOrGet, store.name, true);
+    return promise;
+  }
+
 
   putWithResult<T>(store: Store<T>, val: T): Promise<IDBValidKey> {
     this.checkFinished();
@@ -671,26 +741,33 @@ export class QueryRoot {
 
 
   /**
-   * Get, modify and store an element inside a transaction.
+   * Update objects inside a transaction.
+   *
+   * If the mutation function throws AbortTransaction, the whole transaction will be aborted.
+   * If the mutation function returns undefined or null, no modification will be made.
    */
-  mutate<T>(store: Store<T>, key: any, f: (v: T|undefined) => T|undefined): QueryRoot {
+  mutate<T>(store: Store<T>, key: any, f: (v: T) => T|undefined): QueryRoot {
     this.checkFinished();
     const doPut = (tx: IDBTransaction) => {
-      const reqGet = tx.objectStore(store.name).get(key);
-      reqGet.onsuccess = () => {
-        const r = reqGet.result;
-        let m: T|undefined;
-        try {
-          m = f(r);
-        } catch (e) {
-          if (e === AbortTransaction) {
-            tx.abort();
-            return;
+      const req = tx.objectStore(store.name).openCursor(IDBKeyRange.only(key));
+      req.onsuccess = () => {
+        const cursor = req.result;
+        if (cursor) {
+          const value = cursor.value;
+          let modifiedValue: T|undefined;
+          try {
+            modifiedValue = f(value);
+          } catch (e) {
+            if (e === AbortTransaction) {
+              tx.abort();
+              return;
+            }
+            throw e;
           }
-          throw e;
-        }
-        if (m !== undefined && m !== null) {
-          tx.objectStore(store.name).put(m);
+          if (modifiedValue !== undefined && modifiedValue !== null) {
+            cursor.update(modifiedValue);
+          }
+          cursor.continue();
         }
       };
     };
@@ -702,8 +779,6 @@ export class QueryRoot {
 
   /**
    * Add all object from an iterable to the given object store.
-   * Fails if the object's key is already present
-   * in the object store.
    */
   putAll<T>(store: Store<T>, iterable: T[]): QueryRoot {
     this.checkFinished();
@@ -756,6 +831,38 @@ export class QueryRoot {
                   .then(() => promise);
   }
 
+  /**
+   * Get get objects from a store by their keys.
+   * If no object for a key exists, the resulting position in the array
+   * contains 'undefined'.
+   */
+  getMany<T>(store: Store<T>, keys: any[]): Promise<T[]> {
+    this.checkFinished();
+
+    const { resolve, promise } = openPromise();
+    const results: T[] = [];
+
+    const doGetMany = (tx: IDBTransaction) => {
+      for (const key of keys) {
+        if (key === void 0) {
+          throw Error("key must not be undefined");
+        }
+        const req = tx.objectStore(store.name).get(key);
+        req.onsuccess = () => {
+          results.push(req.result);
+          if (results.length === keys.length) {
+            resolve(results);
+          }
+        };
+      }
+    };
+
+    this.addWork(doGetMany, store.name, false);
+    return Promise.resolve()
+                  .then(() => this.finish())
+                  .then(() => promise);
+  }
+
   /**
    * Get one object from a store by its key.
    */
@@ -810,8 +917,12 @@ export class QueryRoot {
         resolve();
       };
       tx.onabort = () => {
+        console.warn(`aborted ${mode} transaction on stores [${[... this.stores]}]`);
         reject(Error("transaction aborted"));
       };
+      tx.onerror = (e) => {
+        console.warn(`error in transaction`, (e.target as any).error);
+      };
       for (const w of this.work) {
         w(tx);
       }
@@ -822,13 +933,13 @@ export class QueryRoot {
   /**
    * Delete an object by from the given object store.
    */
-  delete(storeName: string, key: any): QueryRoot {
+  delete<T>(store: Store<T>, key: any): QueryRoot {
     this.checkFinished();
     const doDelete = (tx: IDBTransaction) => {
-      tx.objectStore(storeName).delete(key);
+      tx.objectStore(store.name).delete(key);
     };
     this.scheduleFinish();
-    this.addWork(doDelete, storeName, true);
+    this.addWork(doDelete, store.name, true);
     return this;
   }
 
