@@ -14,17 +14,17 @@
  TALER; see the file COPYING.  If not, see <http://www.gnu.org/licenses/>
  */
 
-import {test} from "ava";
-import {Amounts} from "./types";
-import * as types from "./types";
+import { test } from "ava";
+import * as Amounts from "./amounts";
+import { ContractTerms } from "./talerTypes";
 
-const amt = (value: number, fraction: number, currency: string): types.AmountJson => ({value, fraction, currency});
+const amt = (value: number, fraction: number, currency: string): Amounts.AmountJson => ({value, fraction, currency});
 
 test("amount addition (simple)", (t) => {
   const a1 = amt(1, 0, "EUR");
   const a2 = amt(1, 0, "EUR");
   const a3 = amt(2, 0, "EUR");
-  t.true(0 === types.Amounts.cmp(Amounts.add(a1, a2).amount, a3));
+  t.true(0 === Amounts.cmp(Amounts.add(a1, a2).amount, a3));
   t.pass();
 });
 
@@ -39,7 +39,7 @@ test("amount subtraction (simple)", (t) => {
   const a1 = amt(2, 5, "EUR");
   const a2 = amt(1, 0, "EUR");
   const a3 = amt(1, 5, "EUR");
-  t.true(0 === types.Amounts.cmp(Amounts.sub(a1, a2).amount, a3));
+  t.true(0 === Amounts.cmp(Amounts.sub(a1, a2).amount, a3));
   t.pass();
 });
 
@@ -54,14 +54,23 @@ test("amount subtraction (saturation)", (t) => {
 });
 
 
+test("amount parsing", (t) => {
+  const a1 = Amounts.parseOrThrow("TESTKUDOS:10");
+  t.is(a1.currency, "TESTKUDOS");
+  t.is(a1.value, 10);
+  t.is(a1.fraction, 0);
+  t.pass();
+});
+
+
 test("contract terms validation", (t) => {
   const c = {
     H_wire: "123",
-    amount: amt(1, 2, "EUR"),
+    amount: "EUR:1.5",
     auditors: [],
     exchanges: [{master_pub: "foo", url: "foo"}],
     fulfillment_url: "foo",
-    max_fee: amt(1, 2, "EUR"),
+    max_fee: "EUR:1.5",
     merchant_pub: "12345",
     order_id: "test_order",
     pay_deadline: "Date(12346)",
@@ -73,13 +82,13 @@ test("contract terms validation", (t) => {
     wire_method: "test",
   };
 
-  types.ContractTerms.checked(c);
+  ContractTerms.checked(c);
 
   const c1 = JSON.parse(JSON.stringify(c));
   c1.exchanges = [];
 
   try {
-    types.ContractTerms.checked(c1);
+    ContractTerms.checked(c1);
   } catch (e) {
     t.pass();
     return;
