@@ -21,7 +21,12 @@
 // Messages are already documented in wxApi.
 /* tslint:disable:completed-docs */
 
-import * as types from "../types";
+import { AmountJson } from "../amounts";
+import * as dbTypes from "../dbTypes";
+import * as talerTypes from "../talerTypes";
+import * as walletTypes from "../walletTypes";
+
+import { UpgradeResponse } from "./wxApi";
 
 /**
  * Message type information.
@@ -29,7 +34,7 @@ import * as types from "../types";
 export interface MessageMap {
   "balances": {
     request: { };
-    response: types.WalletBalance;
+    response: walletTypes.WalletBalance;
   };
   "dump-db": {
     request: { };
@@ -41,10 +46,6 @@ export interface MessageMap {
     };
     response: void;
   };
-  "get-tab-cookie": {
-    request: { }
-    response: any;
-  };
   "ping": {
     request: { };
     response: void;
@@ -55,7 +56,7 @@ export interface MessageMap {
   };
   "create-reserve": {
     request: {
-      amount: types.AmountJson;
+      amount: AmountJson;
       exchange: string
     };
     response: void;
@@ -64,49 +65,41 @@ export interface MessageMap {
     request: { reservePub: string };
     response: void;
   };
-  "generate-nonce": {
-    request: { }
-    response: string;
-  };
   "confirm-pay": {
-    request: { proposalId: number; };
-    response: types.ConfirmPayResult;
+    request: { proposalId: number; sessionId?: string };
+    response: walletTypes.ConfirmPayResult;
   };
   "check-pay": {
     request: { proposalId: number; };
-    response: types.CheckPayResult;
+    response: walletTypes.CheckPayResult;
   };
   "query-payment": {
     request: { };
-    response: void;
+    response: dbTypes.PurchaseRecord;
   };
   "exchange-info": {
     request: { baseUrl: string };
-    response: types.ExchangeRecord;
+    response: dbTypes.ExchangeRecord;
   };
   "currency-info": {
     request: { name: string };
-    response: types.CurrencyRecord;
+    response: dbTypes.CurrencyRecord;
   };
   "hash-contract": {
     request: { contract: object };
     response: string;
   };
-  "save-proposal": {
-    request: { proposal: types.ProposalRecord };
-    response: void;
-  };
   "reserve-creation-info": {
-    request: { baseUrl: string, amount: types.AmountJson };
-    response: types.ReserveCreationInfo;
+    request: { baseUrl: string, amount: AmountJson };
+    response: walletTypes.ReserveCreationInfo;
   };
   "get-history": {
     request: { };
-    response: types.HistoryRecord[];
+    response: walletTypes.HistoryRecord[];
   };
   "get-proposal": {
     request: { proposalId: number };
-    response: types.ProposalRecord | undefined;
+    response: dbTypes.ProposalDownloadRecord | undefined;
   };
   "get-coins": {
     request: { exchangeBaseUrl: string };
@@ -118,55 +111,47 @@ export interface MessageMap {
   };
   "get-currencies": {
     request: { };
-    response: types.CurrencyRecord[];
+    response: dbTypes.CurrencyRecord[];
   };
   "update-currency": {
-    request: { currencyRecord: types.CurrencyRecord };
+    request: { currencyRecord: dbTypes.CurrencyRecord };
     response: void;
   };
   "get-exchanges": {
     request: { };
-    response: types.ExchangeRecord[];
+    response: dbTypes.ExchangeRecord[];
   };
   "get-reserves": {
     request: { exchangeBaseUrl: string };
-    response: types.ReserveRecord[];
+    response: dbTypes.ReserveRecord[];
   };
   "get-payback-reserves": {
     request: { };
-    response: types.ReserveRecord[];
+    response: dbTypes.ReserveRecord[];
   };
   "withdraw-payback-reserve": {
     request: { reservePub: string };
-    response: void;
+    response: dbTypes.ReserveRecord[];
   };
   "get-precoins": {
     request: { exchangeBaseUrl: string };
-    response: types.PreCoinRecord[];
+    response: dbTypes.PreCoinRecord[];
   };
   "get-denoms": {
     request: { exchangeBaseUrl: string };
-    response: types.DenominationRecord[];
+    response: dbTypes.DenominationRecord[];
   };
   "payback-coin": {
     request: { coinPub: string };
     response: void;
   };
-  "payment-failed": {
-    request: { contractTermsHash: string };
-    response: void;
-  };
-  "payment-succeeded": {
-    request: { contractTermsHash: string; merchantSig: string };
-    response: void;
-  };
   "check-upgrade": {
     request: { };
-    response: void;
+    response: UpgradeResponse;
   };
   "get-sender-wire-infos": {
     request: { };
-    response: void;
+    response: walletTypes.SenderWireInfos;
   };
   "return-coins": {
     request: { };
@@ -180,16 +165,44 @@ export interface MessageMap {
     request: { reportUid: string };
     response: void;
   };
-  "accept-refund": {
-    request: any;
-    response: void;
-  };
   "get-purchase": {
-    request: any;
-    response: void;
+    request: { contractTermsHash: string };
+    response: dbTypes.PurchaseRecord;
   };
   "get-full-refund-fees": {
-    request: { refundPermissions: types.RefundPermission[] };
+    request: { refundPermissions: talerTypes.MerchantRefundPermission[] };
+    response: AmountJson;
+  };
+  "accept-tip": {
+    request: { tipToken: talerTypes.TipToken };
+    response: walletTypes.TipStatus;
+  };
+  "get-tip-status": {
+    request: { tipToken: talerTypes.TipToken };
+    response: walletTypes.TipStatus;
+  };
+  "clear-notification": {
+    request: { };
+    response: void;
+  };
+  "taler-pay": {
+    request: any;
+    response: void;
+  };
+  "download-proposal": {
+    request: { url: string };
+    response: number;
+  };
+  "submit-pay": {
+    request: { contractTermsHash: string, sessionId: string | undefined };
+    response: walletTypes.ConfirmPayResult;
+  };
+  "accept-refund": {
+    request: { refundUrl: string }
+    response: string;
+  };
+  "abort-failed-payment": {
+    request: { contractTermsHash: string }
     response: void;
   };
 }
