@@ -22,28 +22,34 @@
  * @author Florian Dold
  */
 
-import {canonicalizeBaseUrl} from "../../helpers";
+import { canonicalizeBaseUrl } from "../../helpers";
 import * as i18n from "../../i18n";
-import {
-  AmountJson,
-  Amounts,
-  CreateReserveResponse,
-  CurrencyRecord,
-  DenominationRecord,
-  ReserveCreationInfo,
-} from "../../types";
 
-import {ImplicitStateComponent, StateHolder} from "../components";
+import { AmountJson } from "../../amounts";
+import * as Amounts from "../../amounts";
+
 import {
+  CurrencyRecord,
+} from "../../dbTypes";
+import {
+  CreateReserveResponse,
+  ReserveCreationInfo,
+} from "../../walletTypes";
+
+import { ImplicitStateComponent, StateHolder } from "../components";
+import {
+  WalletApiError,
   createReserve,
   getCurrency,
   getExchangeInfo,
   getReserveCreationInfo,
 } from "../wxApi";
 
-import {Collapsible, renderAmount} from "../renderHtml";
+import {
+  WithdrawDetailView,
+  renderAmount,
+} from "../renderHtml";
 
-import * as moment from "moment";
 import * as React from "react";
 import * as ReactDOM from "react-dom";
 import URI = require("urijs");
@@ -80,128 +86,6 @@ class EventTrigger {
 }
 
 
-function renderAuditorDetails(rci: ReserveCreationInfo|null) {
-  console.log("rci", rci);
-  if (!rci) {
-    return (
-      <p>
-        Details will be displayed when a valid exchange provider URL is entered.
-      </p>
-    );
-  }
-  if (rci.exchangeInfo.auditors.length === 0) {
-    return (
-      <p>
-        The exchange is not audited by any auditors.
-      </p>
-    );
-  }
-  return (
-    <div>
-      {rci.exchangeInfo.auditors.map((a) => (
-        <div>
-          <h3>Auditor {a.auditor_url}</h3>
-          <p>Public key: {a.auditor_pub}</p>
-          <p>Trusted: {rci.trustedAuditorPubs.indexOf(a.auditor_pub) >= 0 ? "yes" : "no"}</p>
-          <p>Audits {a.denomination_keys.length} of {rci.numOfferedDenoms} denominations</p>
-        </div>
-      ))}
-    </div>
-  );
-}
-
-function renderReserveCreationDetails(rci: ReserveCreationInfo|null) {
-  if (!rci) {
-    return (
-      <p>
-        Details will be displayed when a valid exchange provider URL is entered.
-      </p>
-    );
-  }
-
-  const denoms = rci.selectedDenoms;
-
-  const countByPub: {[s: string]: number} = {};
-  const uniq: DenominationRecord[] = [];
-
-  denoms.forEach((x: DenominationRecord) => {
-    let c = countByPub[x.denomPub] || 0;
-    if (c === 0) {
-      uniq.push(x);
-    }
-    c += 1;
-    countByPub[x.denomPub] = c;
-  });
-
-  function row(denom: DenominationRecord) {
-    return (
-      <tr>
-        <td>{countByPub[denom.denomPub] + "x"}</td>
-        <td>{renderAmount(denom.value)}</td>
-        <td>{renderAmount(denom.feeWithdraw)}</td>
-        <td>{renderAmount(denom.feeRefresh)}</td>
-        <td>{renderAmount(denom.feeDeposit)}</td>
-      </tr>
-    );
-  }
-
-  function wireFee(s: string) {
-    return [
-      <thead>
-        <tr>
-        <th colSpan={3}>Wire Method {s}</th>
-        </tr>
-        <tr>
-        <th>Applies Until</th>
-        <th>Wire Fee</th>
-        <th>Closing Fee</th>
-        </tr>
-      </thead>,
-      <tbody>
-      {rci!.wireFees.feesForType[s].map((f) => (
-        <tr>
-          <td>{moment.unix(f.endStamp).format("llll")}</td>
-          <td>{renderAmount(f.wireFee)}</td>
-          <td>{renderAmount(f.closingFee)}</td>
-        </tr>
-      ))}
-      </tbody>,
-    ];
-  }
-
-  const withdrawFee = renderAmount(rci.withdrawFee);
-  const overhead = renderAmount(rci.overhead);
-
-  return (
-    <div>
-      <h3>Overview</h3>
-      <p>{i18n.str`Withdrawal fees:`} {withdrawFee}</p>
-      <p>{i18n.str`Rounding loss:`} {overhead}</p>
-      <p>{i18n.str`Earliest expiration (for deposit): ${moment.unix(rci.earliestDepositExpiration).fromNow()}`}</p>
-      <h3>Coin Fees</h3>
-      <table className="pure-table">
-        <thead>
-        <tr>
-          <th>{i18n.str`# Coins`}</th>
-          <th>{i18n.str`Value`}</th>
-          <th>{i18n.str`Withdraw Fee`}</th>
-          <th>{i18n.str`Refresh Fee`}</th>
-          <th>{i18n.str`Deposit Fee`}</th>
-        </tr>
-        </thead>
-        <tbody>
-        {uniq.map(row)}
-        </tbody>
-      </table>
-      <h3>Wire Fees</h3>
-      <table className="pure-table">
-      {Object.keys(rci.wireFees.feesForType).map(wireFee)}
-      </table>
-    </div>
-  );
-}
-
-
 interface ExchangeSelectionProps {
   suggestedExchangeUrl: string;
   amount: AmountJson;
@@ -234,7 +118,8 @@ class ManualSelection extends ImplicitStateComponent<ManualSelectionProps> {
           <input className="url" type="text" spellCheck={false}
                  value={this.url()}
                  key="exchange-url-input"
-                 onInput={(e) => this.onUrlChanged((e.target as HTMLInputElement).value)} />
+                 onInput={(e) => this.onUrlChanged((e.target as HTMLInputElement).value)}
+                 onChange={(e) => this.onUrlChanged((e.target as HTMLInputElement).value)} />
         </div>
         <div className="pure-u-1">
           <button className="pure-button button-success"
@@ -242,6 +127,7 @@ class ManualSelection extends ImplicitStateComponent<ManualSelectionProps> {
                   onClick={() => this.props.onSelect(this.url())}>
             {i18n.str`Select`}
           </button>
+          <span> </span>
           {this.errorMessage()}
         </div>
       </div>
@@ -266,15 +152,12 @@ class ManualSelection extends ImplicitStateComponent<ManualSelectionProps> {
       console.log("getExchangeInfo returned");
       this.isOkay(true);
     } catch (e) {
-      console.log("got error", e);
-      if (e.hasOwnProperty("httpStatus")) {
-        this.errorMessage(`Error: request failed with status ${e.httpStatus}`);
-      } else if (e.hasOwnProperty("errorResponse")) {
-        const resp = e.errorResponse;
-        this.errorMessage(`Error: ${resp.error} (${resp.hint})`);
-      } else {
-        this.errorMessage("invalid exchange URL");
+      if (!(e instanceof WalletApiError)) {
+        // maybe it's something more serious, don't handle here!
+        throw e;
       }
+      console.log(`got error "${e.message} "with detail`, e.detail);
+      this.errorMessage(i18n.str`Invalid exchange URL (${e.message})`);
     }
   }
 
@@ -348,9 +231,7 @@ class ExchangeSelection extends ImplicitStateComponent<ExchangeSelectionProps> {
         <i18n.Translate wrap="p">
           Using exchange provider <strong>{this.url()}</strong>.
           The exchange provider will charge
-          {" "}
-          <span>{renderAmount(totalCost)}</span>
-          {" "}
+          {" "}<span>{renderAmount(totalCost)}</span>{" "}
           in fees.
         </i18n.Translate>
         {trustMessage}
@@ -362,7 +243,7 @@ class ExchangeSelection extends ImplicitStateComponent<ExchangeSelectionProps> {
       return (
         <i18n.Translate wrap="p">
           Waiting for a response from
-          {" "}
+          <span> </span>
           <em>{shortName}</em>
         </i18n.Translate>
       );
@@ -395,16 +276,22 @@ class ExchangeSelection extends ImplicitStateComponent<ExchangeSelectionProps> {
     if (rci.versionMatch.currentCmp === -1) {
       return (
         <p className="errorbox">
-          Your wallet might be outdated.  The exchange has a higher, incompatible
-          protocol version.
+          <i18n.Translate wrap="span">
+          Your wallet (protocol version <span>{rci.walletVersion}</span>) might be outdated.<span> </span>
+          The exchange has a higher, incompatible
+          protocol version (<span>{rci.exchangeVersion}</span>).
+          </i18n.Translate>
         </p>
       );
     }
     if (rci.versionMatch.currentCmp === 1) {
       return (
         <p className="errorbox">
-          The chosen exchange might be outdated.  The exchange has a lower, incompatible
-          protocol version.
+          <i18n.Translate wrap="span">
+          The chosen exchange (protocol version <span>{rci.exchangeVersion}</span> might be outdated.<span> </span>
+          The exchange has a lower, incompatible
+          protocol version than your wallet (protocol version <span>{rci.walletVersion}</span>).
+          </i18n.Translate>
         </p>
       );
     }
@@ -428,12 +315,7 @@ class ExchangeSelection extends ImplicitStateComponent<ExchangeSelectionProps> {
         </button>
         </p>
         {this.renderUpdateStatus()}
-        <Collapsible initiallyCollapsed={true} title="Fee and Spending Details">
-          {renderReserveCreationDetails(this.reserveCreationInfo())}
-        </Collapsible>
-        <Collapsible initiallyCollapsed={true} title="Auditor Details">
-          {renderAuditorDetails(this.reserveCreationInfo())}
-        </Collapsible>
+        <WithdrawDetailView rci={this.reserveCreationInfo()} />
       </div>
     );
   }
@@ -450,13 +332,15 @@ class ExchangeSelection extends ImplicitStateComponent<ExchangeSelectionProps> {
     console.log(exchanges);
     return (
       <div>
-        Please select an exchange.  You can review the details before after your selection.
+        {i18n.str`Please select an exchange.  You can review the details before after your selection.`}
 
         {this.props.suggestedExchangeUrl && (
           <div>
             <h2>Bank Suggestion</h2>
             <button className="pure-button button-success" onClick={() => this.select(this.props.suggestedExchangeUrl)}>
+              <i18n.Translate wrap="span">
               Select <strong>{this.props.suggestedExchangeUrl}</strong>
+              </i18n.Translate>
             </button>
           </div>
         )}
@@ -465,14 +349,16 @@ class ExchangeSelection extends ImplicitStateComponent<ExchangeSelectionProps> {
           <div>
             <h2>Known Exchanges</h2>
             {exchanges.map((e) => (
-              <button className="pure-button button-success" onClick={() => this.select(e.baseUrl)}>
-              Select <strong>{e.baseUrl}</strong>
+              <button key={e.baseUrl} className="pure-button button-success" onClick={() => this.select(e.baseUrl)}>
+                <i18n.Translate>
+                Select <strong>{e.baseUrl}</strong>
+                </i18n.Translate>
               </button>
             ))}
           </div>
         )}
 
-        <h2>Manual Selection</h2>
+        <h2>i18n.str`Manual Selection`</h2>
         <ManualSelection initialUrl={this.url() || ""} onSelect={(url: string) => this.select(url)} />
       </div>
     );
@@ -482,9 +368,9 @@ class ExchangeSelection extends ImplicitStateComponent<ExchangeSelectionProps> {
     return (
       <div>
         <i18n.Translate wrap="p">
-          {"You are about to withdraw "}
-          <strong>{renderAmount(this.props.amount)}</strong>
-          {" from your bank account into your wallet."}
+          You are about to withdraw
+          {" "}<strong>{renderAmount(this.props.amount)}</strong>{" "}
+          from your bank account into your wallet.
         </i18n.Translate>
         {this.selectingExchange() ? this.renderSelect() : this.renderConfirm()}
       </div>
@@ -556,8 +442,8 @@ class ExchangeSelection extends ImplicitStateComponent<ExchangeSelectionProps> {
         amount_fraction: amount.fraction,
         amount_value: amount.value,
         exchange: resp.exchange,
+        exchange_wire_details: JSON.stringify(filteredWireDetails),
         reserve_pub: resp.reservePub,
-        wire_details: JSON.stringify(filteredWireDetails),
       };
       const url = new URI(callback_url).addQuery(q);
       if (!url.is("absolute")) {
@@ -623,7 +509,7 @@ async function main() {
     // TODO: provide more context information, maybe factor it out into a
     // TODO:generic error reporting function or component.
     document.body.innerText = i18n.str`Fatal error: "${e.message}".`;
-    console.error(`got error "${e.message}"`, e);
+    console.error("got error", e);
   }
 }
 
