@@ -26,13 +26,15 @@
  * Imports.
  */
 import * as i18n from "../../i18n";
+
+import { AmountJson } from "../../amounts";
+import * as Amounts from "../../amounts";
+
 import {
-  AmountJson,
-  Amounts,
   HistoryRecord,
   WalletBalance,
   WalletBalanceEntry,
-} from "../../types";
+} from "../../walletTypes";
 
 import { abbrev, renderAmount } from "../renderHtml";
 import * as wxApi from "../wxApi";
@@ -280,7 +282,8 @@ class WalletBalanceView extends React.Component<any, any> {
     if (Amounts.isNonZero(entry.pendingPayment)) {
       payment = (
         <i18n.Translate wrap="span">
-          <span style={{color: "darkblue"}}>
+          <span style={{color: "red"}}>
+            {"-"}
             {renderAmount(entry.pendingPayment)}
           </span>
           {" "}
@@ -358,7 +361,7 @@ function formatHistoryItem(historyItem: HistoryRecord) {
       return (
         <i18n.Translate wrap="p">
           Started to withdraw
-          {" "}{renderAmount(d.requestedAmount)}<span> </span>
+          <span>{renderAmount(d.requestedAmount)}</span>
           from <span>{exchange}</span> (<span>{pub}</span>).
         </i18n.Translate>
       );
@@ -366,7 +369,7 @@ function formatHistoryItem(historyItem: HistoryRecord) {
     case "offer-contract": {
       return (
         <i18n.Translate wrap="p">
-          Merchant <em>{abbrev(d.merchantName, 15)}</em> offered<span> </span>
+          Merchant <em>{abbrev(d.merchantName, 15)}</em> offered
           contract <span>{abbrev(d.contractTermsHash)}</span>.
         </i18n.Translate>
       );
@@ -401,6 +404,22 @@ function formatHistoryItem(historyItem: HistoryRecord) {
         </i18n.Translate>
       );
     }
+    case "tip": {
+      const tipPageUrl = new URI(chrome.extension.getURL("/src/webex/pages/tip.html"));
+      const params = { tip_id: d.tipId, merchant_domain: d.merchantDomain };
+      const url = tipPageUrl.query(params).href();
+      const tipLink = <a href={url} onClick={openTab(url)}>{i18n.str`tip`}</a>;
+      // i18n: Tip
+      return (
+        <>
+          <i18n.Translate wrap="p">
+            Merchant <span>{d.merchantDomain}</span> gave
+            a <span>{tipLink}</span> of <span>{renderAmount(d.amount)}</span>.
+          </i18n.Translate>
+          <span> { d.accepted ? null : <i18n.Translate>You did not accept the tip yet.</i18n.Translate> }</span>
+        </>
+      );
+    }
     default:
       return (<p>{i18n.str`Unknown event (${historyItem.type})`}</p>);
   }
@@ -554,4 +573,7 @@ const el = (
 
 document.addEventListener("DOMContentLoaded", () => {
   ReactDOM.render(el, document.getElementById("content")!);
+  // Will be used by the backend to detect when the popup gets closed,
+  // so we can clear notifications
+  chrome.runtime.connect({name: "popup"});
 });
