@@ -22,6 +22,7 @@
 
 
 import { getTalerStampDate } from "../../helpers";
+
 import {
   CoinRecord,
   CoinStatus,
@@ -29,7 +30,7 @@ import {
   ExchangeRecord,
   PreCoinRecord,
   ReserveRecord,
-} from "../../types";
+} from "../../dbTypes";
 
 import { ImplicitStateComponent, StateHolder } from "../components";
 import {
@@ -42,7 +43,7 @@ import {
   refresh,
 } from "../wxApi";
 
-import { renderAmount } from "../renderHtml";
+import { ExpanderText, renderAmount } from "../renderHtml";
 
 import * as React from "react";
 import * as ReactDOM from "react-dom";
@@ -244,49 +245,6 @@ interface DenominationListProps {
   exchange: ExchangeRecord;
 }
 
-interface ExpanderTextProps {
-  text: string;
-}
-
-class ExpanderText extends ImplicitStateComponent<ExpanderTextProps> {
-  private expanded = this.makeState<boolean>(false);
-  private textArea: any = undefined;
-
-  componentDidUpdate() {
-    if (this.expanded() && this.textArea) {
-      this.textArea.focus();
-      this.textArea.scrollTop = 0;
-    }
-  }
-
-  render(): JSX.Element {
-    if (!this.expanded()) {
-      return (
-        <span onClick={() => { this.expanded(true); }}>
-          {(this.props.text.length <= 10)
-            ?  this.props.text
-            : (
-                <span>
-                  {this.props.text.substring(0, 10)}
-                  <span style={{textDecoration: "underline"}}>...</span>
-                </span>
-              )
-          }
-        </span>
-      );
-    }
-    return (
-      <textarea
-        readOnly
-        style={{display: "block"}}
-        onBlur={() => this.expanded(false)}
-        ref={(e) => this.textArea = e}>
-        {this.props.text}
-      </textarea>
-    );
-  }
-}
-
 class DenominationList extends ImplicitStateComponent<DenominationListProps> {
   private expanded = this.makeState<boolean>(false);
   private denoms = this.makeState<undefined|DenominationRecord[]>(undefined);
@@ -403,9 +361,9 @@ interface ExchangesListState {
   exchanges?: ExchangeRecord[];
 }
 
-class ExchangesList extends React.Component<any, ExchangesListState> {
-  constructor() {
-    super();
+class ExchangesList extends React.Component<{}, ExchangesListState> {
+  constructor(props: {}) {
+    super(props);
     const port = chrome.runtime.connect();
     port.onMessage.addListener((msg: any) => {
       if (msg.notify) {
