@@ -22,23 +22,30 @@
 /**
  * Imports.
  */
+import { AmountJson } from "../amounts";
 import {
-  AmountJson,
-  CheckPayResult,
   CoinRecord,
-  ConfirmPayResult,
   CurrencyRecord,
   DenominationRecord,
   ExchangeRecord,
   PreCoinRecord,
+  ProposalDownloadRecord,
   PurchaseRecord,
-  QueryPaymentResult,
-  RefundPermission,
-  ReserveCreationInfo,
   ReserveRecord,
+} from "../dbTypes";
+import {
+  CheckPayResult,
+  ConfirmPayResult,
+  ReserveCreationInfo,
   SenderWireInfos,
+  TipStatus,
   WalletBalance,
-} from "../types";
+} from "../walletTypes";
+
+import {
+  MerchantRefundPermission,
+  TipToken,
+} from "../talerTypes";
 
 import { MessageMap, MessageType } from "./messages";
 
@@ -65,11 +72,25 @@ export interface UpgradeResponse {
 }
 
 
-async function callBackend<T extends MessageType>(type: T, detail: MessageMap[T]["request"]): Promise<any> {
-  return new Promise<any>((resolve, reject) => {
+/**
+ * Error thrown when the function from the backend (via RPC) threw an error.
+ */
+export class WalletApiError extends Error {
+  constructor(message: string, public detail: any) {
+    super(message);
+  }
+}
+
+
+async function callBackend<T extends MessageType>(
+  type: T,
+  detail: MessageMap[T]["request"],
+): Promise<MessageMap[T]["response"]> {
+  return new Promise<MessageMap[T]["response"]>((resolve, reject) => {
     chrome.runtime.sendMessage({ type, detail }, (resp) => {
-      if (resp && resp.error) {
-        reject(resp);
+      if (typeof resp === "object" && resp && resp.error) {
+        const e = new WalletApiError(resp.message, resp);
+        reject(e);
       } else {
         resolve(resp);
       }
@@ -195,7 +216,7 @@ export function payback(coinPub: string): Promise<void> {
 /**
  * Get a proposal stored in the wallet by its proposal id.
  */
-export function getProposal(proposalId: number) {
+export function getProposal(proposalId: number): Promise<ProposalDownloadRecord | undefined> {
   return callBackend("get-proposal", { proposalId });
 }
 
@@ -209,8 +230,15 @@ export function checkPay(proposalId: number): Promise<CheckPayResult> {
 /**
  * Pay for a proposal.
  */
-export function confirmPay(proposalId: number): Promise<ConfirmPayResult> {
-  return callBackend("confirm-pay", { proposalId });
+export function confirmPay(proposalId: number, sessionId: string | undefined): Promise<ConfirmPayResult> {
+  return callBackend("confirm-pay", { proposalId, sessionId });
+}
+
+/**
+ * Replay paying for a purchase.
+ */
+export function submitPay(contractTermsHash: string, sessionId: string | undefined): Promise<ConfirmPayResult> {
+  return callBackend("submit-pay", { contractTermsHash, sessionId });
 }
 
 /**
@@ -220,15 +248,6 @@ export function hashContract(contract: object): Promise<string> {
   return callBackend("hash-contract", { contract });
 }
 
-
-/**
- * Save a proposal in the wallet.  Returns the proposal id that
- * the proposal is stored under.
- */
-export function saveProposal(proposal: any): Promise<number> {
-  return callBackend("save-proposal", { proposal });
-}
-
 /**
  * Mark a reserve as confirmed.
  */
@@ -239,40 +258,10 @@ export function confirmReserve(reservePub: string): Promise<void> {
 /**
  * Query for a payment by fulfillment URL.
  */
-export function queryPayment(url: string): Promise<QueryPaymentResult> {
+export function queryPaymentByFulfillmentUrl(url: string): Promise<PurchaseRecord> {
   return callBackend("query-payment", { url });
 }
 
-/**
- * Mark a payment as succeeded.
- */
-export function paymentSucceeded(contractTermsHash: string, merchantSig: string): Promise<void> {
-  return callBackend("payment-succeeded", { contractTermsHash, merchantSig });
-}
-
-/**
- * Mark a payment as succeeded.
- */
-export function paymentFailed(contractTermsHash: string): Promise<void> {
-  return callBackend("payment-failed", { contractTermsHash });
-}
-
-/**
- * Get the payment cookie for the current tab, or undefined if no payment
- * cookie was set.
- */
-export function getTabCookie(): Promise<any> {
-  return callBackend("get-tab-cookie", { });
-}
-
-/**
- * Generate a contract nonce (EdDSA key pair), store it in the wallet's
- * database and return the public key.
- */
-export function generateNonce(): Promise<string> {
-  return callBackend("generate-nonce", { });
-}
-
 /**
  * Check upgrade information
  */
@@ -336,12 +325,6 @@ export function getReport(reportUid: string): Promise<any> {
   return callBackend("get-report", { reportUid });
 }
 
-/**
- * Apply a refund that we got from the merchant.
- */
-export function acceptRefund(refundData: any): Promise<number> {
-  return callBackend("accept-refund", refundData);
-}
 
 /**
  * Look up a purchase in the wallet database from
@@ -355,6 +338,57 @@ export function getPurchase(contractTermsHash: string): Promise<PurchaseRecord>
  * Get the refund fees for a refund permission, including
  * subsequent refresh and unrefreshable coins.
  */
-export function getFullRefundFees(args: { refundPermissions: RefundPermission[] }): Promise<AmountJson> {
+export function getFullRefundFees(args: { refundPermissions: MerchantRefundPermission[] }): Promise<AmountJson> {
   return callBackend("get-full-refund-fees", { refundPermissions: args.refundPermissions });
 }
+
+
+/**
+ * Get the status of processing a tip.
+ */
+export function getTipStatus(tipToken: TipToken): Promise<TipStatus> {
+  return callBackend("get-tip-status", { tipToken });
+}
+
+/**
+ * Mark a tip as accepted by the user.
+ */
+export function acceptTip(tipToken: TipToken): Promise<TipStatus> {
+  return callBackend("accept-tip", { tipToken });
+}
+
+
+/**
+ * Clear notifications that the wallet shows to the user.
+ */
+export function clearNotification(): Promise<void> {
+  return callBackend("clear-notification", { });
+}
+
+/**
+ * Trigger taler payment processing (for payment, tipping and refunds).
+ */
+export function talerPay(msg: any): Promise<void> {
+  return callBackend("taler-pay", msg);
+}
+
+/**
+ * Download a contract.
+ */
+export function downloadProposal(url: string): Promise<number> {
+  return callBackend("download-proposal", { url });
+}
+
+/**
+ * Download a refund and accept it.
+ */
+export function acceptRefund(refundUrl: string): Promise<string> {
+  return callBackend("accept-refund", { refundUrl });
+}
+
+/**
+ * Abort a failed payment and try to get a refund.
+ */
+export function abortFailedPayment(contractTermsHash: string) {
+  return callBackend("abort-failed-payment", { contractTermsHash });
+}
