@@ -30,20 +30,29 @@ import {
   Index,
   Store,
 } from "../query";
+
+import { AmountJson } from "../amounts";
+
 import {
-  AmountJson,
   ConfirmReserveRequest,
   CreateReserveRequest,
   Notifier,
-  ProposalRecord,
   ReturnCoinsRequest,
-} from "../types";
+} from "../walletTypes";
+
 import {
-  Stores,
-  WALLET_DB_VERSION,
   Wallet,
 } from "../wallet";
 
+import { isFirefox } from "./compat";
+
+import {
+  PurchaseRecord,
+  Stores,
+  WALLET_DB_VERSION,
+} from "../dbTypes";
+
+
 import { ChromeBadge } from "./chromeBadge";
 import { MessageType } from "./messages";
 import * as wxApi from "./wxApi";
@@ -51,6 +60,7 @@ import * as wxApi from "./wxApi";
 import URI = require("urijs");
 import Port = chrome.runtime.Port;
 import MessageSender = chrome.runtime.MessageSender;
+import { TipToken } from "../talerTypes";
 
 
 const DB_NAME = "taler";
@@ -82,15 +92,6 @@ function handleMessage(sender: MessageSender,
       const db = needsWallet().db;
       return importDb(db, detail.dump);
     }
-    case "get-tab-cookie": {
-      if (!sender || !sender.tab || !sender.tab.id) {
-        return Promise.resolve();
-      }
-      const id: number = sender.tab.id;
-      const info: any = paymentRequestCookies[id] as any;
-      delete paymentRequestCookies[id];
-      return Promise.resolve(info);
-    }
     case "ping": {
       return Promise.resolve();
     }
@@ -104,7 +105,7 @@ function handleMessage(sender: MessageSender,
         }
       }
       deleteDb();
-      chrome.browserAction.setBadgeText({ text: "" });
+      setBadgeText({ text: "" });
       console.log("reset done");
       if (!currentWallet) {
         reinitWallet();
@@ -127,14 +128,17 @@ function handleMessage(sender: MessageSender,
       const req = ConfirmReserveRequest.checked(d);
       return needsWallet().confirmReserve(req);
     }
-    case "generate-nonce": {
-      return needsWallet().generateNonce();
-    }
     case "confirm-pay": {
       if (typeof detail.proposalId !== "number") {
         throw Error("proposalId must be number");
       }
-      return needsWallet().confirmPay(detail.proposalId);
+      return needsWallet().confirmPay(detail.proposalId, detail.sessionId);
+    }
+    case "submit-pay": {
+      if (typeof detail.contractTermsHash !== "string") {
+        throw Error("contractTermsHash must be a string");
+      }
+      return needsWallet().submitPay(detail.contractTermsHash, detail.sessionId);
     }
     case "check-pay": {
       if (typeof detail.proposalId !== "number") {
@@ -155,7 +159,7 @@ function handleMessage(sender: MessageSender,
           return Promise.resolve(msg);
         }
       }
-      return needsWallet().queryPayment(detail.url);
+      return needsWallet().queryPaymentByFulfillmentUrl(detail.url);
     }
     case "exchange-info": {
       if (!detail.baseUrl) {
@@ -177,11 +181,6 @@ function handleMessage(sender: MessageSender,
         return hash;
       });
     }
-    case "save-proposal": {
-      console.log("handling save-proposal", detail);
-      const checkedRecord = ProposalRecord.checked(detail.proposal);
-      return needsWallet().saveProposal(checkedRecord);
-    }
     case "reserve-creation-info": {
       if (!detail.baseUrl || typeof detail.baseUrl !== "string") {
         return Promise.resolve({ error: "bad url" });
@@ -250,25 +249,6 @@ function handleMessage(sender: MessageSender,
       }
       return needsWallet().payback(detail.coinPub);
     }
-    case "payment-failed": {
-      // For now we just update exchanges (maybe the exchange did something
-      // wrong and the keys were messed up).
-      // FIXME: in the future we should look at what actually went wrong.
-      console.error("payment reported as failed");
-      needsWallet().updateExchanges();
-      return Promise.resolve();
-    }
-    case "payment-succeeded": {
-      const contractTermsHash = detail.contractTermsHash;
-      const merchantSig = detail.merchantSig;
-      if (!contractTermsHash) {
-        return Promise.reject(Error("contractHash missing"));
-      }
-      if (!merchantSig) {
-        return Promise.reject(Error("merchantSig missing"));
-      }
-      return needsWallet().paymentSucceeded(contractTermsHash, merchantSig);
-    }
     case "get-sender-wire-infos": {
       return needsWallet().getSenderWireInfos();
     }
@@ -305,8 +285,6 @@ function handleMessage(sender: MessageSender,
       return;
     case "get-report":
       return logging.getReport(detail.reportUid);
-    case "accept-refund":
-      return needsWallet().acceptRefund(detail.refund_permissions);
     case "get-purchase": {
       const contractTermsHash = detail.contractTermsHash;
       if (!contractTermsHash) {
@@ -316,6 +294,47 @@ function handleMessage(sender: MessageSender,
     }
     case "get-full-refund-fees":
       return needsWallet().getFullRefundFees(detail.refundPermissions);
+    case "accept-refund":
+      return needsWallet().acceptRefund(detail.refundUrl);
+    case "get-tip-status": {
+      const tipToken = TipToken.checked(detail.tipToken);
+      return needsWallet().getTipStatus(tipToken);
+    }
+    case "accept-tip": {
+      const tipToken = TipToken.checked(detail.tipToken);
+      return needsWallet().acceptTip(tipToken);
+    }
+    case "clear-notification": {
+      return needsWallet().clearNotification();
+    }
+    case "download-proposal": {
+      return needsWallet().downloadProposal(detail.url);
+    }
+    case "abort-failed-payment": {
+      if (!detail.contractTermsHash) {
+        throw Error("contracTermsHash not given");
+      }
+      return needsWallet().abortFailedPayment(detail.contractTermsHash);
+    }
+    case "taler-pay": {
+      const senderUrl = sender.url;
+      if (!senderUrl) {
+        console.log("can't trigger payment, no sender URL");
+        return;
+      }
+      const tab = sender.tab;
+      if (!tab) {
+        console.log("can't trigger payment, no sender tab");
+        return;
+      }
+      const tabId = tab.id;
+      if (typeof tabId !== "string") {
+        console.log("can't trigger payment, no sender tab id");
+        return;
+      }
+      talerPay(detail, senderUrl, tabId);
+      return;
+    }
     default:
       // Exhaustiveness check.
       // See https://www.typescriptlang.org/docs/handbook/advanced-types.html
@@ -382,13 +401,108 @@ class ChromeNotifier implements Notifier {
 }
 
 
-/**
- * Mapping from tab ID to payment information (if any).
- *
- * Used to pass information from an intercepted HTTP header to the content
- * script on the page.
- */
-const paymentRequestCookies: { [n: number]: any } = {};
+async function talerPay(fields: any, url: string, tabId: number): Promise<string | undefined> {
+  if (!currentWallet) {
+    console.log("can't handle payment, no wallet");
+    return undefined;
+  }
+
+  const w = currentWallet;
+
+  const goToPayment = (p: PurchaseRecord): string => {
+    const nextUrl = new URI(p.contractTerms.fulfillment_url);
+    nextUrl.addSearch("order_id", p.contractTerms.order_id);
+    if (p.lastSessionSig) {
+      nextUrl.addSearch("session_sig", p.lastSessionSig);
+    }
+    return nextUrl.href();
+  };
+
+  if (fields.resource_url) {
+    const p = await w.queryPaymentByFulfillmentUrl(fields.resource_url);
+    console.log("query for resource url", fields.resource_url, "result", p);
+    if (p && (fields.session_id === undefined || fields.session_id === p.lastSessionId)) {
+      return goToPayment(p);
+    }
+  }
+  if (fields.contract_url) {
+    const proposalId = await w.downloadProposal(fields.contract_url);
+    const uri = new URI(chrome.extension.getURL("/src/webex/pages/confirm-contract.html"));
+    if (fields.session_id) {
+      uri.addSearch("sessionId", fields.session_id);
+    }
+    uri.addSearch("proposalId", proposalId);
+    const redirectUrl = uri.href();
+    return redirectUrl;
+  }
+  if (fields.offer_url) {
+    return fields.offer_url;
+  }
+  if (fields.refund_url) {
+    console.log("processing refund");
+    const uri = new URI(chrome.extension.getURL("/src/webex/pages/refund.html"));
+    return uri.query({ refundUrl: fields.refund_url }).href();
+  }
+  if (fields.tip) {
+    const uri = new URI(chrome.extension.getURL("/src/webex/pages/tip.html"));
+    return uri.query({ tip_token: fields.tip }).href();
+  }
+  return undefined;
+}
+
+
+function getTab(tabId: number): Promise<chrome.tabs.Tab> {
+  return new Promise((resolve, reject) => {
+    chrome.tabs.get(tabId, (tab: chrome.tabs.Tab) => resolve(tab));
+  });
+}
+
+
+function setBadgeText(options: chrome.browserAction.BadgeTextDetails) {
+  // not supported by all browsers ...
+  if (chrome && chrome.browserAction && chrome.browserAction.setBadgeText) {
+    chrome.browserAction.setBadgeText(options);
+  } else {
+    console.warn("can't set badge text, not supported", options);
+  }
+}
+
+
+function waitMs(timeoutMs: number): Promise<void> {
+  return new Promise((resolve, reject) => {
+      chrome.extension.getBackgroundPage().setTimeout(() => resolve(), timeoutMs);
+  });
+}
+
+
+function makeSyncWalletRedirect(url: string,
+                                tabId: number,
+                                oldUrl: string,
+                                params?: {[name: string]: string | undefined}): object {
+  const innerUrl = new URI(chrome.extension.getURL("/src/webex/pages/" + url));
+  if (params) {
+    for (const key in params) {
+      if (params[key]) {
+        innerUrl.addSearch(key, params[key]);
+      }
+    }
+  }
+  const outerUrl = new URI(chrome.extension.getURL("/src/webex/pages/redirect.html"));
+  outerUrl.addSearch("url", innerUrl);
+  if (isFirefox()) {
+    // Some platforms don't support the sync redirect (yet), so fall back to
+    // async redirect after a timeout.
+    const doit = async() => {
+      await waitMs(150);
+      const tab = await getTab(tabId);
+      if (tab.url === oldUrl) {
+        chrome.tabs.update(tabId, { url: outerUrl.href() });
+      }
+    };
+    doit();
+  }
+  return { redirectUrl: outerUrl.href() };
+}
 
 
 /**
@@ -398,6 +512,11 @@ const paymentRequestCookies: { [n: number]: any } = {};
  * in this tab.
  */
 function handleHttpPayment(headerList: chrome.webRequest.HttpHeader[], url: string, tabId: number): any {
+  if (!currentWallet) {
+    console.log("can't handle payment, no wallet");
+    return;
+  }
+
   const headers: { [s: string]: string } = {};
   for (const kv of headerList) {
     if (kv.value) {
@@ -409,6 +528,9 @@ function handleHttpPayment(headerList: chrome.webRequest.HttpHeader[], url: stri
     contract_url: headers["x-taler-contract-url"],
     offer_url: headers["x-taler-offer-url"],
     refund_url: headers["x-taler-refund-url"],
+    resource_url: headers["x-taler-resource-url"],
+    session_id: headers["x-taler-session-id"],
+    tip: headers["x-taler-tip"],
   };
 
   const talerHeaderFound = Object.keys(fields).filter((x: any) => (fields as any)[x]).length !== 0;
@@ -420,20 +542,49 @@ function handleHttpPayment(headerList: chrome.webRequest.HttpHeader[], url: stri
     return;
   }
 
-  const payDetail = {
-    contract_url: fields.contract_url,
-    offer_url: fields.offer_url,
-    refund_url: fields.refund_url,
-  };
+  console.log("got pay detail", fields);
 
-  console.log("got pay detail", payDetail);
+  // Synchronous fast path for existing payment
+  if (fields.resource_url) {
+    const result = currentWallet.getNextUrlFromResourceUrl(fields.resource_url);
+    if (result && (fields.session_id === undefined || fields.session_id === result.lastSessionId)) {
+      return { redirectUrl: result.nextUrl };
+    }
+  }
+  // Synchronous fast path for new contract
+  if (fields.contract_url) {
+    return makeSyncWalletRedirect("confirm-contract.html", tabId, url, {
+      contractUrl: fields.contract_url,
+      resourceUrl: fields.resource_url,
+      sessionId: fields.session_id,
+    });
+  }
 
-  // This cookie will be read by the injected content script
-  // in the tab that displays the page.
-  paymentRequestCookies[tabId] = {
-    payDetail,
-    type: "pay",
-  };
+  // Synchronous fast path for tip
+  if (fields.tip) {
+    return makeSyncWalletRedirect("tip.html", tabId, url, { tip_token: fields.tip });
+  }
+
+  // Synchronous fast path for refund
+  if (fields.refund_url) {
+    console.log("processing refund");
+    return makeSyncWalletRedirect("refund.html", tabId, url, { refundUrl: fields.refund_url });
+  }
+
+  // We need to do some asynchronous operation, we can't directly redirect
+  talerPay(fields, url, tabId).then((nextUrl) => {
+    if (nextUrl) {
+      // We use chrome.tabs.executeScript instead of chrome.tabs.update
+      // because the latter is buggy when it does not execute in the same
+      // (micro-?)task as the header callback.
+      chrome.tabs.executeScript({
+        code: `document.location.href = decodeURIComponent("${encodeURI(nextUrl)}");`,
+        runAt: "document_start",
+      });
+    }
+  });
+
+  return;
 }
 
 
@@ -458,8 +609,9 @@ function handleBankRequest(wallet: Wallet, headerList: chrome.webRequest.HttpHea
     if (reservePub !== undefined) {
       console.log(`confirming reserve ${reservePub} via 201`);
       wallet.confirmReserve({reservePub});
+    } else {
+      console.warn("got 'X-Taler-Operation: confirm-reserve' without 'X-Taler-Reserve-Pub'");
     }
-    console.warn("got 'X-Taler-Operation: confirm-reserve' without 'X-Taler-Reserve-Pub'");
     return;
   }
 
@@ -474,9 +626,8 @@ function handleBankRequest(wallet: Wallet, headerList: chrome.webRequest.HttpHea
       console.log("202 not understood (X-Taler-Callback-Url missing)");
       return;
     }
-    let amountParsed;
     try {
-      amountParsed = JSON.parse(amount);
+      JSON.parse(amount);
     } catch (e) {
       const errUri = new URI(chrome.extension.getURL("/src/webex/pages/error.html"));
       const p = {
@@ -504,7 +655,7 @@ function handleBankRequest(wallet: Wallet, headerList: chrome.webRequest.HttpHea
     const redirectUrl = uri.query(params).href();
     console.log("redirecting to", redirectUrl);
     // FIXME: use direct redirect when https://bugzilla.mozilla.org/show_bug.cgi?id=707624 is fixed
-    chrome.tabs.update(tabId, {url: redirectUrl});
+    chrome.tabs.update(tabId, { url: redirectUrl });
     return;
   }
 
@@ -537,7 +688,7 @@ async function reinitWallet() {
     currentWallet.stop();
     currentWallet = undefined;
   }
-  chrome.browserAction.setBadgeText({ text: "" });
+  setBadgeText({ text: "" });
   const badge = new ChromeBadge();
   let db: IDBDatabase;
   try {
@@ -676,6 +827,22 @@ export async function wxMain() {
   });
 
 
+  // Clear notifications both when the popop opens,
+  // as well when it closes.
+  chrome.runtime.onConnect.addListener((port) => {
+    if (port.name === "popup") {
+      if (currentWallet) {
+        currentWallet.clearNotification();
+      }
+      port.onDisconnect.addListener(() => {
+          if (currentWallet) {
+            currentWallet.clearNotification();
+          }
+      });
+    }
+  });
+
+
   // Handlers for catching HTTP requests
   chrome.webRequest.onHeadersReceived.addListener((details) => {
     const wallet = currentWallet;
@@ -728,7 +895,7 @@ function openTalerDb(): Promise<IDBDatabase> {
               for (const indexName in (si as any)) {
                 if ((si as any)[indexName] instanceof Index) {
                   const ii: Index<any, any> = (si as any)[indexName];
-                  s.createIndex(ii.indexName, ii.keyPath);
+                  s.createIndex(ii.indexName, ii.keyPath, ii.options);
                 }
               }
             }
@@ -740,7 +907,7 @@ function openTalerDb(): Promise<IDBDatabase> {
             chrome.tabs.create({
               url: chrome.extension.getURL("/src/webex/pages/reset-required.html"),
             });
-            chrome.browserAction.setBadgeText({text: "err"});
+            setBadgeText({text: "err"});
             chrome.browserAction.setBadgeBackgroundColor({color: "#F00"});
             throw Error("incompatible DB");
           }
